@@ -1,7 +1,7 @@
 #!/usr/bin/env python
-from Complex import *
+from Quaternion import Quaternion
 
-__revision__ = "$Id: EPS.py 67 2005-11-27 17:31:07Z const $"
+__revision__ = "$Id: EPS.py 71 2005-12-04 20:08:21Z const $"
 
 class EPS(list):
 
@@ -20,20 +20,20 @@ class EPS(list):
             if not hasattr(v, "__iter__"):
                 v = v,
             list.append(self, "%s%s\n" % (
-                str.join("", map(lambda v: "%s\t" % v, v)), k,
+                str.join("", ("%s\t" % x for x in v)), k,
                 ))
 
     def stroke(self, L, **kwargs):
         list.append(self, "gsave\n")
         list.append(self, "newpath\n")
         self.append(**kwargs)
-        list.append(self, "%g\t%g\tmoveto\n" % L.zero)
-        self.extend("%g\t%g\tlineto\n" % z[:2] for z in L)
+        list.append(self, "%g\t%g\tmoveto\n" % (L.zero[0], L.zero[1]))
+        self.extend("%g\t%g\tlineto\n" % (q[0], q[1]) for q in L)
         if self.__bbox is None:
-            self.__bbox = [Complex(L.power, z) for z in L.bounds]
+            self.__bbox = L.bounds
         else:
             for z in L.bounds:
-                adjust_bounds(self.__bbox, Complex(L.power, z))
+                self.__bbox = z & self.__bbox[0], z | self.__bbox[1]
         list.append(self, "stroke\n")
         list.append(self, "grestore\n")
 
@@ -41,7 +41,8 @@ class EPS(list):
         if self.__bbox is None:
             bbox = 0, 0, 0, 0
         else:
-            bbox = self.__bbox[0].tuple() + self.__bbox[1].tuple()
+            bbox = (self.__bbox[0][0], self.__bbox[0][1],
+                    self.__bbox[1][0], self.__bbox[1][1])
         f.write("%!PS-Adobe-3.0 EPSF 3.0\n")
         f.write("%%%%Creator: %s\n" % __name__)
         f.write("%%%%Title: %s\n" % self.__prop["title"])
