@@ -3,11 +3,11 @@ from OpenGL.GL import *
 from OpenGL.GLUT import *
 import sys, time
 
-__revision__ = "$Id: GL.py 67 2005-11-27 17:31:07Z const $"
+__revision__ = "$Id: GL.py 72 2005-12-06 21:58:37Z const $"
 
 class GL(list):
 
-    __slots__ = "__prop"
+    __slots__ = "__prop", "__fc"
 
     def __init__(self, argv = sys.argv, **kwargs):
         list.__init__(self)
@@ -15,31 +15,24 @@ class GL(list):
             distance = 3,
             color = (0, 0, 0, 0),
             size = (800, 600),
-            light0 = (1, 1, 0, 1),
-            light1 = (1, 0.4, 1, 1),
-            light2 = (0.2, 1, 1, 1),
             )
         self.__prop.update(kwargs)
         glutInit(argv)
         glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGB | GLUT_DEPTH)
-        glutCreateWindow(argv[0])
+        glutCreateWindow(self.__prop.setdefault("title", argv[0]))
         glutHideWindow()
         glClearColor(*self.__prop["color"])
-        glEnable(GL_LIGHTING)
-        for i in range(3):
-            glEnable(GL_LIGHT0 + i)
-            glLightfv(GL_LIGHT0 + i, GL_DIFFUSE, self.__prop["light%u" % i])
-        glLightfv(GL_LIGHT0, GL_POSITION, (0, 0, -1, 0))
-        glLightfv(GL_LIGHT1, GL_POSITION, (-3**0.5, 0, 1, 0))
-        glLightfv(GL_LIGHT2, GL_POSITION, (3**0.5, 0, 1, 0))
         glEnable(GL_DEPTH_TEST)
+        glEnable(GL_FOG)
+        glFogf(GL_FOG_MODE, GL_LINEAR)
+        glFogf(GL_FOG_START, self.__prop["distance"] - 1)
+        glFogf(GL_FOG_END, self.__prop["distance"] + 2)
+        glFogf(GL_FOG_DENSITY, 0.2)
         glutDisplayFunc(self.__display)
         glutIdleFunc(glutPostRedisplay)
         glutReshapeFunc(self.__reshape)
 
     def append(self, L, **kwargs):
-        if L.power != 3:
-            raise RuntimeError
         prop = {
             "color": (1, 1, 1),
             "axis": (0, 1, 0),
@@ -50,9 +43,9 @@ class GL(list):
         glNewList(l, GL_COMPILE)
         glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, prop["color"])
         glBegin(GL_LINE_STRIP)
-        glVertex3d(*L.zero)
-        for z in L:
-            glVertex3d(*z)
+        glVertex3d(L.zero[1], L.zero[2], L.zero[3])
+        for q in L:
+            glVertex3d(q[1], q[2], q[3])
         glEnd()
         glEndList()
         list.append(self, (l, prop))
@@ -69,6 +62,7 @@ class GL(list):
             glCallList(l)
             glPopMatrix()
         glutSwapBuffers()
+        self.__fc[0] += 1
 
     def __reshape(self, width, height):
         if(width > height):
@@ -84,10 +78,20 @@ class GL(list):
             glOrtho(-1, 1, -1, 1, -1, 1)
         glMatrixMode(GL_MODELVIEW)
 
-    def mainloop(self):
+    def __timer(self, value = None):
+        t = time.time()
+        if value is not None:
+            [f, c] = self.__fc
+            glutSetWindowTitle("%s [%.1f fps]" % (self.__prop["title"],
+                                                  f / (t - c)))
+        self.__fc = [0, t]
+        glutTimerFunc(1000, self.__timer, 0)
+
+    def __call__(self):
         glutShowWindow()
-        if self.__prop["fullscreen"]:
+        if self.__prop.get("fullscreen"):
             glutFullScreen()
         else:
             glutReshapeWindow(*self.__prop["size"])
+        self.__timer(None)
         glutMainLoop()
