@@ -1,20 +1,15 @@
 #!/usr/bin/env python
-from Complex import *
+from Quaternion import Quaternion
 
-__revision__ = "$Id: LSystem.py 25 2005-09-28 12:39:03Z const $"
+__revision__ = "$Id: LSystem.py 71 2005-12-04 20:08:21Z const $"
 
 class LSystem(object):
 
-    __slots__ = (
-        "production", "state",
-        "zero", "depth",
-        "__power", "__bounds",
-        )
+    __slots__ = "production", "state", "zero", "depth", "__bounds"
 
-    def __new__(cls, power):
+    def __new__(cls):
         new = object.__new__(cls)
-        new.__power = long(power)
-        new.__bounds = Complex(new.__power, ()), Complex(new.__power, ())
+        new.__bounds = Quaternion(), Quaternion()
         new.production = (1,),
         new.state = (1,),
         new.zero = ()
@@ -23,25 +18,23 @@ class LSystem(object):
 
     def __getattribute__(self, attr):
         if attr == "bounds":
-            return map(Complex.tuple, self.__bounds)
-        elif attr == "power":
-            return self.__power
+            return self.__bounds
         v = object.__getattribute__(self, attr)
         if attr in ["production", "state"]:
-            return map(Complex.tuple, v)
+            return [q() for q in v]
         elif attr == "zero":
-            return v.tuple()
+            return v()
         else:
             return v
 
     def __setattr__(self, attr, value):
         if attr in ["production", "state"]:
-            v = [Complex(self.__power, x) for x in value]
+            v = [Quaternion(*x) for x in value]
             if attr == "production":
-                _s = sum(v, Complex(self.__power, ()))
+                _s = sum(v, Quaternion())
                 v = [x / _s for x in v]
         elif attr == "zero":
-            v = Complex(self.__power, value)
+            v = Quaternion(*value)
         elif attr == "depth":
             v = long(value)
         else:
@@ -62,10 +55,11 @@ class LSystem(object):
             yield u
 
     def __iter__(self):
-        curr = object.__getattribute__(self, "zero").copy()
-        self.__bounds = curr.copy(), curr.copy()
+        curr = object.__getattribute__(self, "zero")
+        self.__bounds = curr, curr
         for u in object.__getattribute__(self, "state"):
             for v in self.__process(u, self.depth):
                 curr += v
-                adjust_bounds(self.__bounds, curr)
-                yield curr.tuple()
+                self.__bounds = (curr & self.__bounds[0],
+                                 curr | self.__bounds[1])
+                yield curr()
